@@ -17,6 +17,9 @@ class FinishWork(Message):
     # 自己实现自己的finish work做好资源回收
 
     def do_finish_work(self):
+        if self.agentClient:
+            logger.info("bizWorkId: %s stop" % self.agentClient.biz_work_id)
+            self.agentClient.biz_work_id = None
         logger.info("do finish work")
         return True
 
